@@ -78,16 +78,28 @@ msv_ctxt_init (const char *url)
 {
 
   msv_ctxt_t ctx;
+  char *env;
 
   ctx = malloc (sizeof (struct msv_ctxt));
+  if (!ctx)
+    return NULL;
 
   if (url)
     ctx->socket_location = strdup (url);
+  else if ((env = getenv ("MONKEYSPHERE_VALIDATION_AGENT_SOCKET")))
+    ctx->socket_location = strdup (env);
   else
     {
-      ctx->socket_location =
-	strdup (getenv ("MONKEYSPHERE_VALIDATION_AGENT_SOCKET"));
+      free (ctx);
+      return NULL;
     }
+
+  if (!ctx->socket_location)
+    {
+      free (ctx);
+      return NULL;
+    }
+
   return ctx;
 }
 
@@ -231,9 +243,6 @@ msv_query_agent (msv_ctxt_t ctx, struct msv_query q,
   pkc = json_object ();
   peer = json_object ();
 
-  response = malloc (sizeof (struct msv_response));
-  *response_ptr = response;
-
   if ((j_pkcdata = json_string (q.pkcdata)) &&
       (j_pkctype = json_string (q.pkctype)) &&
       (j_peername = json_string (q.peername)) &&
@@ -346,6 +355,16 @@ msv_query_agent (msv_ctxt_t ctx, struct msv_query q,
       return LIBMSV_ERROR_CURLCODE;
     }
 
+  if (!(response = malloc (sizeof (struct msv_response))))
+    {
+      curl_easy_cleanup (c);
+      free (req);
+      curl_slist_free_all (slist);
+      return LIBMSV_ERROR_NOMEM;
+    }
+  response->message = NULL;
+  *response_ptr = response;
+
   j = json_loads (buf, 0, &je);
   free (buf);
 
@@ -366,6 +385,15 @@ msv_query_agent (msv_ctxt_t ctx, struct msv_query q,
   curl_easy_cleanup (c);
   free (req);
 
+  if (!response->message)
+    {
+      /* strdup returned NULL, which suggests a memory allocation
+         failure */
+      msv_response_destroy (response);
+      *response_ptr = NULL;
+      return LIBMSV_ERROR_NOMEM;
+    }
+
   return !(response->valid);
 }
 
