@@ -1,6 +1,8 @@
 #ifndef _MSV_H
 #define _MSV_H 1
 
+#include <unistd.h>
+
 /** @file msv/msv.h
  *  @brief main public libmsv header file
  */
@@ -50,6 +52,12 @@
  */
 #define LIBMSV_ERROR_UNEXPECTED_RESPONSE 7
 
+/**
+ * @def LIBMSV_ERROR_NOMEM
+ * @brief necessary memory allocation failed
+ */
+#define LIBMSV_ERROR_NOMEM 8
+
 /**
  * @typedef msv_ctxt_t
  * @brief opaque MSVA context
@@ -70,6 +78,16 @@ struct msv_query
   const char *pkcdata; /**< public key carrier data encoded in the format specified by \a pkctype */
 };
 
+#ifdef HAVE_VAR_ATTRIBUTE_DEPRECATED
+# define MSV_DEPRECATED(X) X __attribute__((deprecated))
+#elif __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 5)
+# define MSV_DEPRECATED(X) X __attribute__((deprecated))
+#elif __GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 1)
+# define MSV_DEPRECATED(X) X __attribute__((__deprecated__))
+#else
+# define MSV_DEPRECATED(X) X
+#endif
+
 /**
  * @struct msv_response
  * @brief a response from the MSVA
@@ -78,7 +96,7 @@ struct msv_response
 {
   int valid; /**< 0 for invalid, 1 for valid */
   char *message; /**< text response to be displayed to the user */
-  size_t sz; /**< length of the buffer allocated to \a message */
+  size_t MSV_DEPRECATED(sz); /**< length of the buffer allocated to \a message */
 };
 
 /**
